CSS codec — cssutils 0.9.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- cssutils 0.9.8 documentation »

# CSS codec

Python codec for CSS.

#### Previous topic

scripts

#### Next topic

`encutils` module

### This Page

- Show Source

### Quick search

Enter search terms or a module, class or function name.

### Navigation

- index
- modules |
- next |
- previous |
- cssutils 0.9.8 documentation »

© Copyright 2004-2011, Christof Höke. Created using Sphinx 1.1.2.